@@ -21,7 +21,6 @@ import (
 	"github.com/evilsocket/islazy/fs"
 	"github.com/evilsocket/islazy/ops"
 	"github.com/evilsocket/islazy/str"
-	"github.com/evilsocket/islazy/tui"
 )
 
 type WiFiModule struct {
@@ -489,6 +488,8 @@ func (mod *WiFiModule) setFrequencies(freqs []int) {
 		channels = append(channels, network.Dot11Freq2Chan(freq))
 	}
 	mod.State.Store("channels", channels)
+
+	mod.Info("channels: %v", channels)
 }
 
 func (mod *WiFiModule) Configure() error {
@@ -550,7 +551,7 @@ func (mod *WiFiModule) Configure() error {
 
 		if mod.txPower > 0 {
 			if err := network.SetInterfaceTxPower(ifName, mod.txPower); err != nil {
-				mod.Warning("could not set interface %s txpower to %d, 'Set Tx Power' requests not supported", ifName, mod.txPower)
+				mod.Warning("could not set interface %s txpower to %d, 'Set Tx Power' requests not supported: %v", ifName, mod.txPower, err)
 			} else {
 				mod.Debug("interface %s txpower set to %d", ifName, mod.txPower)
 			}
@@ -579,9 +580,12 @@ func (mod *WiFiModule) Configure() error {
 				// second fatal error, just bail
 				return fmt.Errorf("error while activating handle: %s", err)
 			} else {
-				// first fatal error, try again without setting the interface in monitor mode
-				mod.Warning("error while activating handle: %s, %s", err, tui.Bold("interface might already be monitoring. retrying!"))
-				opts.Monitor = false
+				// first fatal error, forcing monitor mode 
+				// https://github.com/bettercap/bettercap/issues/819
+				opts.Monitor = false;
+				if err := network.ForceMonitorMode(ifName); err != nil {
+					return err
+				}
 			}
 		}
 	}
