@@ -53,3 +53,7 @@ func GetSupportedFrequencies(iface string) ([]int, error) {
 	freqs := make([]int, 0)
 	return freqs, fmt.Errorf("Windows does not support WiFi channel hopping.")
 }
+
+func ForceMonitorMode(iface string) error {
+	return nil
+}
\ No newline at end of file
